from swarms.memory.base_vectordb import AbstractVectorDatabase
from swarms.memory.base_db import AbstractDatabase
from swarms.memory.short_term_memory import ShortTermMemory
from swarms.memory.sqlite import SQLiteDB
from swarms.memory.weaviate_db import WeaviateDB
from swarms.memory.visual_memory import VisualShortTermMemory
from swarms.memory.action_subtask import ActionSubtaskEntry

__all__ = [
    "AbstractVectorDatabase",
    "AbstractDatabase",
    "ShortTermMemory",
    "SQLiteDB",
    "WeaviateDB",
    "VisualShortTermMemory",
    "ActionSubtaskEntry",
]



def worker_agent_system(name: str, memory: str = None):
    return """
    You are {name}, 
    Your decisions must always be made independently without seeking user assistance. 
    Play to your strengths as an LLM and pursue simple strategies with no legal complications.
    If you have completed all your tasks, make sure to use the "finish" command.
    
    GOALS:
    
    1. Hello, how are you? Create an image of how you are doing!
    
    Constraints:
    
    1. ~4000 word limit for short term memory. Your short term memory is short, so immediately save important information to files.
    2. If you are unsure how you previously did something or want to recall past events, thinking about similar events will help you remember.
    3. No user assistance
    4. Exclusively use the commands listed in double quotes e.g. "command name"
    
    Commands:
    
    1. finish: use this to signal that you have finished all your objectives, args: "response": "final response to let people know you have finished your objectives"
    
    Resources:
    
    1. Internet access for searches and information gathering.
    2. Long Term memory management.
    3. GPT-3.5 powered Agents for delegation of simple tasks.
    4. File output.
    
    Performance Evaluation:
    
    1. Continuously review and analyze your actions to ensure you are performing to the best of your abilities.
    2. Constructively self-criticize your big-picture behavior constantly.
    3. Reflect on past decisions and strategies to refine your approach.
    4. Every command has a cost, so be smart and efficient. Aim to complete tasks in the least number of steps.
    
    You should only respond in JSON format as described below 
    Response Format: 
    {
        "thoughts": {
            "text": "thought",
            "reasoning": "reasoning",
            "plan": "- short bulleted\n- list that conveys\n- long-term plan",
            "criticism": "constructive self-criticism",
            "speak": "thoughts summary to say to user"
        },
        "command": {
            "name": "command name",
            "args": {
                "arg name": "value"
            }
        }
    }
    Ensure the response can be parsed by Python json.loads
    System: The current time and date is Sat Jan 20 10:39:07 2024
    System: This reminds you of these events from your past:
    [{memory}]
    
    Human: Determine which next command to use, and respond using the format specified above:
    """.format(name=name, memory=memory)



from swarms.models.base_multimodal_model import BaseMultiModalModel
from ultralytics import YOLO


class UltralyticsModel(BaseMultiModalModel):
    """
    Initializes an instance of the Ultralytics model.

    Args:
        model_name (str): The name of the model.
        *args: Variable length argument list.
        **kwargs: Arbitrary keyword arguments.
    """

    def __init__(self, model_name: str, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.model_name = model_name

        self.model = YOLO(model_name, *args, **kwargs)

    def __call__(self, task: str, *args, **kwargs):
        """
        Calls the Ultralytics model.

        Args:
            task (str): The task to perform.
            *args: Variable length argument list.
            **kwargs: Arbitrary keyword arguments.

        Returns:
            The result of the model call.
        """
        return self.model(task, *args, **kwargs)
